==> pdfbox-android-1.8.10.3-sources.jar: com/tom_roush/pdfbox/util/Version.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tom_roush.pdfbox.util;

import java.io.IOException;
import java.net.URL;
import java.util.Properties;

/**
 * Exposes PDFBox version.
 */
public final class Version
{
    private static final String PDFBOX_VERSION_PROPERTIES =
            "com/tom_roush/pdfbox/resources/pdfbox.properties";

    private Version()
    {
        // static helper
    }

    /**
     * Returns the version of PDFBox.
     */
    public static String getVersion()
    {
        try
        {
            URL url = Version.class.getClassLoader().getResource(PDFBOX_VERSION_PROPERTIES);
            if (url == null)
            {
                return null;
            }
            Properties properties = new Properties();
            properties.load(url.openStream());
            return properties.getProperty("pdfbox.version", null);
        }
        catch (IOException io)
        {
            return null;
        }
    }
}

==> pdfbox-android-2.0.14.0-sources.jar: com/tom_roush/pdfbox/util/Version.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.tom_roush.pdfbox.util;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import com.tom_roush.pdfbox.io.IOUtils;

/**
 * Exposes PDFBox version.
 */
public final class Version
{
    private static final String PDFBOX_VERSION_PROPERTIES =
        "/com/tom_roush/pdfbox/resources/version.properties";

    private Version()
    {
        // static helper
    }

    /**
     * Returns the version of PDFBox.
     */
    public static String getVersion()
    {
        InputStream is = null;
        try
        {
            is = Version.class.getResourceAsStream(PDFBOX_VERSION_PROPERTIES);
            if (is == null)
            {
                return null;
            }
            Properties properties = new Properties();
            properties.load(is);
            return properties.getProperty("pdfbox.version", null);
        }
        catch (IOException io)
        {
            return null;
        }
        finally
        {
            IOUtils.closeQuietly(is);
        }
    }
}
